Dialects — SQLAlchemy 1.0 Documentation

Release: 1.0.18 | Release Date: July 24, 2017

# SQLAlchemy 1.0 Documentation

# Dialects

The dialect is the system SQLAlchemy uses to communicate with various types of DBAPI implementations and databases. The sections that follow contain reference documentation and notes specific to the usage of each backend, as well as notes for the various DBAPIs.

All dialects require that an appropriate DBAPI driver is installed.

## Included Dialects

- Firebird
- Microsoft SQL Server
- MySQL
- Oracle
- PostgreSQL
- SQLite
- Sybase

## External Dialects

Changed in version 0.8: As of SQLAlchemy 0.8, several dialects have been moved to external projects, and dialects for new databases will also be published as external projects. The rationale here is to keep the base SQLAlchemy install and test suite from growing inordinately large.

The “classic” dialects such as SQLite, MySQL, Postgresql, Oracle, SQL Server, and Firebird will remain in the Core for the time being.

Changed in version 1.0: The Drizzle dialect has been moved into the third party system.

Current external dialect projects for SQLAlchemy include:

### Production Ready

- ibm_db_sa - driver for IBM DB2 and Informix, developed jointly by IBM and SQLAlchemy developers.
- sqlalchemy-redshift - driver for Amazon Redshift, adapts the existing Postgresql/psycopg2 driver.
- sqlalchemy_exasol - driver for EXASolution.
- sqlalchemy-sqlany - driver for SAP Sybase SQL Anywhere, developed by SAP.
- sqlalchemy-monetdb - driver for MonetDB.
- snowflake-sqlalchemy - driver for Snowflake.

### Experimental / Incomplete

Dialects that are in an incomplete state or are considered somewhat experimental.

- CALCHIPAN - Adapts Pandas dataframes to SQLAlchemy.
- sqlalchemy-cubrid - driver for the CUBRID database.

### Attic

Dialects in the “attic” are those that were contributed for SQLAlchemy long ago but have received little attention or demand since then, and are now moved out to their own repositories in at best a semi-working state. Community members interested in these dialects should feel free to pick up on their current codebase and fork off into working libraries.

- sqlalchemy-access - driver for Microsoft Access.
- sqlalchemy-drizzle - driver for the Drizzle MySQL variant.
- sqlalchemy-informixdb - driver for the informixdb DBAPI.
- sqlalchemy-maxdb - driver for the MaxDB database